@@ -3,4 +3,4 @@ pub mod info;
 pub mod install;
 pub mod list;
 pub mod uninstall;
-pub mod use_;
+pub mod use_version;
