@@ -33,6 +33,25 @@ pub fn is_semver(version: &str) -> bool {
   semver_parse(version).is_ok()
 }
 
+#[cfg(not(windows))]
 pub fn is_china_mainland() -> bool {
   env::var("LANG").map(|lng| lng.starts_with("zh_CN.")).unwrap_or(false)
 }
+
+#[cfg(windows)]
+pub fn is_china_mainland() -> bool {
+  use winapi::ctypes::c_int;
+  use winapi::um::winnls::GetUserDefaultLocaleName;
+
+  // The maximum number of characters allowed for this string is 85,
+  // including a terminating null character.
+  // https://docs.microsoft.com/en-us/windows/win32/intl/locale-sname
+  let mut buf = [0u16; 85];
+  let len = unsafe { GetUserDefaultLocaleName(buf.as_mut_ptr(), buf.len() as c_int) };
+
+  if len <= 0 {
+    return false;
+  }
+
+  String::from_utf16_lossy(&buf).starts_with("zh-CN")
+}
